@@ -211,6 +211,9 @@ class PreseemNetworkMetadataModel(object):
                 for it, index in self._index.items():
                     for ia, ir in index.items():
                         ir.clear()
+                        if ia == '_LOWER':  # lowercase value index
+                            ir[None] = {n.lower(): r for n, r in (self.refs.get(it) or {}).items()}
+                            continue
                         for ref in (self.refs.get(it) or {}).values():
                             attr = ref.attributes.get(ia)
                             if attr:
@@ -243,6 +246,12 @@ class PreseemNetworkMetadataModel(object):
                     index = self._index.get(ref.type)
                     if index is not None:
                         for ia, ir in index.items():
+                            if ia == '_LOWER':
+                                refs = ir.get(None)
+                                if refs is None:
+                                    refs = ir[None] = {}
+                                refs[ref.value.lower()] = ref
+                                continue
                             if cur:
                                 # Remove the old ref from any indexes
                                 attr = cur.attributes.get(ia)
@@ -282,6 +291,11 @@ class PreseemNetworkMetadataModel(object):
                     index = self._index.get(ref.type)
                     if index is not None:
                         for ia, ir in index.items():
+                            if ia == '_LOWER':
+                                refs = ir.get(None)
+                                if refs:
+                                    refs.pop(ref.value.lower(), None)
+                                continue
                             attr = ref.attributes.get(ia)
                             if attr:
                                 refs = ir.get(attr)
@@ -308,7 +322,7 @@ class PreseemNetworkMetadataModel(object):
             _resolve_refs(refs, obj.attributes)
         return obj
 
-    def get_ref_index(self, reftype, attr, val):
+    def get_ref_index(self, reftype, attr, val=None):
         """Get a map of reference types of a type with a given attr value."""
         return self._index[reftype][attr].get(val)
 
